=====
Demos
=====

.. raw:: html

   <a href="basic_tutorial.html"><button style="background-color:#307FC1;color:white;border-color:#307FC1;width: 330.0px; height: 50.0px;border-radius: 8px;margin-bottom: 10px;margin-left: 10px">Learn how to calculate GWB spectra with popstock</button></a>

   <br />

.. currentmodule:: popstock

.. toctree::
   :maxdepth: 1
   :hidden:
   
   basic_tutorial
   
